const gitClient = require('../clients/git-client');

module.exports = {
    checkStateBeforeDeploying: checkStateBeforeDeploying,
    deployHostedSkill: deployHostedSkill
}

/**
 * Deploys an Alexa Hosted Skill
 */
function deployHostedSkill(projectPath, doDebug) {
    const verbosityOptions = {
        showCommand: doDebug ? true : false,
        showOutput: doDebug ? true : false
    }
    console.log(`\n- Checking for uncommited changes in dev branch before deploying...`);
    checkStateBeforeDeploying(projectPath);
    if (gitClient.isBranchOneAheadOfBranchTwo(projectPath, 'master', 'dev')) {
        console.warn(`\n[Warn]: Some commits on master branch are not in dev branch\n`);
    }
    console.log(`\n- Merging dev branch into master branch...`);
    gitClient.mergeBranchOneIntoBranchTwo(projectPath, 'dev', 'master', verbosityOptions);
    console.log(`\n- Pushing dev branch...`);
    gitClient.push(projectPath, 'dev', verbosityOptions);
    console.log(`\n- Pushing master branch...`);
    gitClient.push(projectPath, 'master', verbosityOptions);
    console.log();
}

/**
 * Checks if current branch is dev and if the state is not dirty
 * @param {String} projectPath 
 */
function checkStateBeforeDeploying(projectPath) {
    if (gitClient.getCurrentBranch(projectPath) !== 'dev') {
        throw(`Please switch to "dev" branch and make sure your latest changes are there.\nTo switch, run the following command: git checkout dev`);
    }

    if (gitClient.isBranchStateDirty(projectPath)) {
        throw(`You have uncommited changes in your dev branch. Commit your changes first`);
    }
}

