const path = require('path');
const fs = require('fs');
const { execSync, spawnSync } = require('child_process');
const jsonUtility = require('./json-utility');
const profileHelper = require('./profile-helper');
const gitClient = require('../clients/git-client');


module.exports = {
    isAlexaHostedSkill: isAlexaHostedSkill,
    getSkillId: getSkillId,
    hasFileChanged: hasFileChanged,
    gitDiff: gitDiff
}

/**
 * Checks if working directory contains .ask/config and checks if isHostedSkill
 * @param {String} [Required] projectDir directory to check
 */
function isAlexaHostedSkill(projectDir, profile) {

    // Check if config file exists in .ask hidden directory in current directory
    const configFilePath = path.join(projectDir, '.ask', 'config');
    if (!fs.existsSync(configFilePath)) {
        return false;
    }

    // Check if config file contains isHostedSkill and if it is set to true
    const config = jsonUtility.read(configFilePath);
    if (!(config.alexaHosted && config.alexaHosted.isAlexaHostedSkill)) {
        return false;
    }

    return true;
}

/**
 * Gets skillId from .ask/config file using the specified profile in parameter
 * @param {String} projectDir [Required] Root directory of the skill project
 * @param {String} profile [Optional] ASK Profile. If not provided, uses the runtime profile
 */
function getSkillId(projectDir, profile) {

    profile = profileHelper.runtimeProfile(profile);

    const projectConfigFile = path.join(projectDir, '.ask', 'config');
    const askConfig = jsonUtility.read(projectConfigFile);

    const skillId = jsonUtility.getPropertyValueFromObject(askConfig, ['deploy_settings', profile, 'skill_id']);

    return skillId;
}

function hasFileChanged(projectPath, filepath) {
    return gitClient.hasFileChanged(projectPath, filepath);
}

function gitDiff(projectPath, branch, doDebug) {
    const verbosityOptions = {
        showCommand: doDebug ? true : false,
        showOutput: doDebug ? true : false
    }
    return gitClient.diffRemote(projectPath, branch, verbosityOptions);
}